pub struct TimestampData {
pub timestamp_mode: InterfaceTimestampMode,
pub hardware: Option<Timestamp>,
pub software: Option<Timestamp>,
}Fields
timestamp_mode: InterfaceTimestampModeThe timestamping mode requested by the user when creating the socket.
If this was not available, this is set to None.
hardware: Option<Timestamp>The hardware based timestamp returned by the OS
software: Option<Timestamp>The software based timestamp returned by the OS
Implementations
Sourceimpl TimestampData
impl TimestampData
Sourcepub fn selected_timestamp(self) -> Option<Timestamp>
pub fn selected_timestamp(self) -> Option<Timestamp>
Returns the timestamp type selected by the requested timestamping mode.
If the requested timestamping mode is None or if the requested timestamp
is not available, this function will return None.